@@ -44,6 +44,8 @@ class TqdmStream: # pylint: disable=too-few-public-methods
 
 async def play_rec(playback, path):
     """Play a recorded game."""
+    if not playback:
+        raise RuntimeError('playback not supported')
     from mgz.playback import Client, progress_bar
     with open(path, 'rb') as handle:
         summary = Summary(handle)
@@ -72,10 +74,9 @@ async def extract_rec(playback, path, select=None):
 def print_info(path):
     """Print basic info."""
     with open(path, 'rb') as handle:
-        header = mgz.header.parse_stream(handle)
-        handle.seek(0)
         summary = Summary(handle)
         dataset = summary.get_dataset()
+        header = summary.get_header()
         print('-------------')
         print(tabulate([
             ['Path', path],
@@ -246,7 +247,7 @@ def get_args():
     """Get arguments."""
     parser = argparse.ArgumentParser()
     parser.add_argument('-p', '--playback',
-                        default=os.environ.get('AOC_PLAYBACK', 'localhost:8080:/tmp'))
+                        default=os.environ.get('AOC_PLAYBACK', ''))
     subparsers = parser.add_subparsers(dest='cmd')
     subparsers.required = True
     info = subparsers.add_parser(CMD_INFO)
