@@ -127,7 +127,16 @@ DE_MAP_NAMES = {
     139: 'Golden Swamp',
     140: 'Four Lakes',
     141: 'Land Nomad',
-    145: 'Fall of Rome'
+    142: 'Battle on Ice',
+    143: 'El Dorado',
+    144: 'Fall of Axum',
+    145: 'Fall of Rome',
+    146: 'Majapahit Empire',
+    147: 'Amazon Tunnel',
+    148: 'Coastal Forest',
+    149: 'African Clearing',
+    150: 'Atacama',
+    151: 'Seize the Mountain'
 }
 
 MAP_NAMES = {
@@ -255,4 +264,4 @@ VALID_BUILDINGS = [
     331, 357, 463, 464, 465, 484, 487, 488, 490, 491, 498, 562, 563, 564, 565, 584,
     585, 586, 587, 597, 598, 617, 621, 659, 661, 665, 667, 669, 673, 674, 734, 789,
     790, 792, 793, 794, 796, 797, 798, 800, 801, 802, 804, 1189
-] + [1553, 387, 110, 785, 1002] + [1021, 1187, 1251] + [946, 947, 886, 888, 881, 879, 938, 871] # 5th Age, Realms, DE, Various
+] + [1553, 387, 110, 785, 1002] + [1021, 1187, 1251, 1665] + [946, 947, 886, 888, 881, 879, 938, 871] + [1665] # 5th Age, Realms, DE, Various, DE DLC1
