@@ -348,9 +348,11 @@ def ActionEnum(ctx):
         save=27,
         ai_waypoint=31,
         chapter=32,
+        de_unknown_35=35,
+        de_unknown_37=37,
         de_attackmove=33,
         de_autoscout=38,
-        de_unknown=39,
+        de_unknown_39=39,
         ai_command=53,
         ai_queue=100,
         research=101,
@@ -360,6 +362,7 @@ def ActionEnum(ctx):
         delete=106,
         attackground=107,
         tribute=108,
+        de_unknown_109=109,
         repair=110,
         release=111,
         multiqueue=112,
@@ -374,6 +377,9 @@ def ActionEnum(ctx):
         townbell=127,
         backtowork=128,
         de_queue=129,
+        de_unknown_130=130,
+        de_unknown_131=131,
+        de_unknown_135=135,
         postgame=255,
         default=Pass
     )
