@@ -26,7 +26,8 @@ de = "de"/Struct(
     "dlc_count"/Int32ul,
     "dlc_ids"/Array(lambda ctx: ctx.dlc_count, Int32ul),
     "dataset_ref"/Int32ul,
-    "difficulty"/DifficultyEnum(Int32ul),
+    Peek("difficulty_id"/Int32ul),
+    DifficultyEnum("difficulty"/Int32ul),
     "selected_map_id"/Int32ul,
     "resolved_map_id"/Int32ul,
     "reveal_map"/Int32ul,
@@ -114,6 +115,7 @@ de = "de"/Struct(
     Bytes(19),
     If(lambda ctx: ctx._.save_version >= 13.13, Bytes(5)),
     If(lambda ctx: ctx._.save_version >= 13.17, Bytes(9)),
+    If(lambda ctx: ctx._.save_version >= 20.06, Bytes(1)),
     de_string,
     Bytes(5),
     If(lambda ctx: ctx._.save_version >= 13.13, Byte),
